@@ -36,8 +36,11 @@ def deploy_to_pypi(setup_path=None):
         if not (setup_path / 'setup.py').exists():
             raise FileNotFoundError(mylogging.return_str("Setup.py file not found. Setup `setup_path` param."))
 
-    shutil.rmtree(setup_path / 'dist')
-    shutil.rmtree(setup_path / 'build')
+    try:
+        shutil.rmtree(setup_path / 'dist')
+        shutil.rmtree(setup_path / 'build')
+    except Exception:
+        pass
 
     subprocess.run(['python', 'setup.py', 'sdist', 'bdist_wheel'], cwd=setup_path, shell=True, check=True)
 
