@@ -17,8 +17,9 @@ def set_root(set_root_path=None):
     Args:
         root_path ((str, pathlib.Path)): Path to project root.
     """
-    if set_root_path:
-        root_path = Path(set_root_path)
+    global root_path
+
+    root_path = Path(set_root_path) if set_root_path else root_path
 
     if not root_path.as_posix() in sys.path:
         sys.path.insert(0, root_path.as_posix())
